@@ -1,61 +1,62 @@
 package IO::AIO::Util;
 
 use strict;
+use warnings;
 
-use base qw( Exporter );
+use base qw(Exporter);
 use IO::AIO 2;
-use File::Spec::Functions qw( splitpath splitdir catpath catdir );
+use File::Spec::Functions qw(splitpath splitdir catpath catdir);
 use POSIX ();
 
-our $VERSION = '0.06';
-our @EXPORT_OK = qw( aio_mkpath aio_mktree );
+our $VERSION = '0.07';
+our @EXPORT_OK = qw(aio_mkpath aio_mktree);
 
-sub aio_mkpath ( $$;$ ) {
-    my ( $path, $mode, $cb ) = @_;
+sub aio_mkpath ($$;$) {
+    my ($path, $mode, $cb) = @_;
 
     my $pri = aioreq_pri;
     my $grp = aio_group $cb;
 
     # Default is success.
-    $grp->result( 0 );
+    $grp->result(0);
 
     my @make;
     my $statgrp = add $grp aio_group sub {
         my $dirgrp = add $grp aio_group;
-        for my $path ( @make ) {
+        for my $path (@make) {
             aioreq_pri $pri;
             add $dirgrp aio_mkdir $path, $mode, sub {
-                if ( $_[0] ) {
-                    $grp->result( $_[0] );
-                    $grp->errno( $! );
+                if ($_[0]) {
+                    $grp->result($_[0]);
+                    $grp->errno($!);
                     return $grp->cancel_subs;
                 }
             };
         }
     };
 
-    my ( $vol, $dir, undef ) = splitpath( $path, 1 );
-    my @dirs = splitdir( $dir );
+    my ($vol, $dir, undef) = splitpath($path, 1);
+    my @dirs = splitdir($dir);
 
-    while ( @dirs ) {
+    while (@dirs) {
         my $path = $path;
 
         aioreq_pri $pri;
         add $statgrp aio_stat $path, sub {
             # stat was successful
-            if ( not $_[0] ) {
+            if (not $_[0]) {
                 # fail if part of the expected path is not a dir
-                if ( ! -d _ ) {
-                    $grp->result( -1 );
-                    $grp->errno( &POSIX::ENOTDIR );
+                if (not -d _) {
+                    $grp->result(-1);
+                    $grp->errno(&POSIX::ENOTDIR);
                     return $grp->cancel_subs;
                 }
                 return $statgrp->cancel_subs;
             }
             # stat was not succesful, for reason other than non-existence
-            elsif ( $_[0] and $! != &POSIX::ENOENT ) {
-                $grp->result( -1 );
-                $grp->errno( $! );
+            elsif ($_[0] and $! != &POSIX::ENOENT) {
+                $grp->result(-1);
+                $grp->errno($!);
                 return $grp->cancel_subs;
             }
 
@@ -64,7 +65,7 @@ sub aio_mkpath ( $$;$ ) {
     }
     continue {
         pop @dirs;
-        $path = catpath( $vol, catdir( @dirs ), '' );
+        $path = catpath($vol, catdir(@dirs), '');
     }
 
     $grp;
